# FILE: makerules.tcl
#
# This file controls the application 'pimake' by defining rules which
# describe how to build the applications and/or extensions produced by
# the source code in this directory.
#
# NOTICE: Please see the file ../../LICENSE
#
# Last modified on: $Date: 1998/08/05 15:37:47 $
# Last modified by: $Author: dgp $
#
# Verify that this script is being sourced by pimake
if {[llength [info commands MakeRule]] == 0} {
    error "'[info script]' must be evaluated by pimake"
}
#
########################################################################

set objects {
	dstring
       	evoc
	functions
	nb
	stopwatch
}

MakeRule Define {
    -targets            build
    -dependencies       [concat configure tclIndex [Platform StaticLibrary nb]]
}

MakeRule Define {
    -targets            configure
    -dependencies       [Platform Name]
}

MakeRule Define {
    -targets            [Platform Name]
    -dependencies       {}
    -script             {MakeDirectory [Platform Name]}
}

MakeRule Define {
    -targets            tclIndex
    -dependencies       [glob -nocomplain *.tcl]
    -script             {
                         MakeTclIndex .
                        }
}

MakeRule Define {
    -targets            [Platform StaticLibrary nb]
    -dependencies	[Platform Objects [concat errhandlers $objects]]
    -script		[format {
			    eval file delete [Platform StaticLibrary nb]
			    Platform MakeLibrary -out nb -obj {errhandlers %s}
			    Platform IndexLibrary nb
			} $objects]
}

foreach o $objects { 
    MakeRule Define {
        -targets	[Platform Objects $o]
        -dependencies	[concat [list [Platform Name]] \
			        [[CSourceFile New _ $o.cc] Dependencies]]
        -script		[format {Platform Compile C++ -opt 1 \
			        -inc [[CSourceFile New _ %s.cc] DepPath] \
			        -src %s.cc -out %s
			} $o $o $o]
    }
}

# Compilation of errhandlers.cc is handled specially because optimization level
# 1 causes pointer trouble on some platforms.
if {[catch {
    [Oc_Config RunPlatform] GetValue \
            program_compiler_c++_property_optimization_breaks_varargs
} _] || !$_} {
MakeRule Define {
    -targets		[Platform Objects errhandlers]
    -dependencies	[concat [list [Platform Name]] [[CSourceFile New _ \
			        errhandlers.cc] Dependencies]]
    -script		{Platform Compile C++ -opt 1 -inc \
			        [[CSourceFile New _ errhandlers.cc] DepPath] \
			        -src errhandlers.cc -out errhandlers
			}
}
} else {
MakeRule Define {
    -targets		[Platform Objects errhandlers]
    -dependencies	[concat [list [Platform Name]] [[CSourceFile New _ \
			        errhandlers.cc] Dependencies]]
    -script		{Platform Compile C++ -opt 0 -inc \
			        [[CSourceFile New _ errhandlers.cc] DepPath] \
			        -src errhandlers.cc -out errhandlers
			}
}
}

MakeRule Define {
    -targets            distclean
    -dependencies       clean
    -script             {DeleteFiles [Platform Name]}
}
 
MakeRule Define {
    -targets            clean
    -dependencies       mostlyclean
}
 
MakeRule Define {
    -targets            mostlyclean
    -dependencies       objclean
    -script             {eval DeleteFiles [concat tclIndex \
			        [Platform StaticLibrary nb]]}
}
 
MakeRule Define {
    -targets            objclean
    -dependencies       {}
    -script             [format {
			    eval DeleteFiles [Platform Objects {errhandlers %s}]
			} $objects]
}

unset objects
